pub fn parse<T: Parse>(input: TokenStream) -> Result<T>Expand description
Parse tokens of source code into the chosen syntax tree node.
pub fn parse<T: Parse>(input: TokenStream) -> Result<T>Parse tokens of source code into the chosen syntax tree node.