macro_rules! Token {
(struct) => { ... };
(enum) => { ... };
(:) => { ... };
(,) => { ... };
}Expand description
A type-macro that expands to the name of the Rust type representation of a given token.
macro_rules! Token {
(struct) => { ... };
(enum) => { ... };
(:) => { ... };
(,) => { ... };
}A type-macro that expands to the name of the Rust type representation of a given token.